API Reference
=============

This section contains the complete API documentation for Pavise, automatically generated from docstrings.

.. toctree::
   :maxdepth: 2

   pandas
   polars
   types
   validators
   exceptions
